@@ -1,15 +1,14 @@
 import typing
 
-from .binary_search import binary_search
+from .curried_doubling_search import curried_doubling_search
 
 
 def doubling_search(
     predicate: typing.Callable[[int], bool],
     lower_bound: int = 0,
 ) -> int:
-    """
-    Find the positive integer threshold below which a search criteria is never
-    satisfied and above which it is always satisfied.
+    """Find the positive integer threshold below which a search criteria is
+    never satisfied and above which it is always satisfied.
 
     Parameters
     ----------
@@ -25,12 +24,4 @@ def doubling_search(
         The lowest integer value that satisfies the search criteria.
     """
 
-    assert lower_bound >= 0, lower_bound
-
-    bound = 1
-    while not predicate(lower_bound + bound):
-        bound *= 2
-
-    prev_bound = bound // 2
-    prev_guess = lower_bound + prev_bound
-    return binary_search(predicate, prev_guess, lower_bound + bound)
+    return curried_doubling_search(predicate)(lower_bound)
